========
Créditos
========

Desenvolvedor
-------------

PyCEPCorreios foi desenvolvido originalmente por:

* Michell Stuttgart <michellstut@gmail.com>

Contribuidores
--------------

Agradecimentos aos seguintes contribuidores pelo esforço de fazer a PyCEPCorreios
melhor:

* `Aldo Soares <https://github.com/aldo774>`_
